"""Auto-generated file, do not edit by hand. AR metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_AR = PhoneMetadata(id='AR', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='[01389]\\d{1,4}', possible_length=(2, 3, 4, 5)),
    toll_free=PhoneNumberDesc(national_number_pattern='[09]\\d{2}|1(?:[02-9]\\d?|1[0-24-9]?)', example_number='111', possible_length=(2, 3)),
    emergency=PhoneNumberDesc(national_number_pattern='10[017]|911', example_number='101', possible_length=(3,)),
    short_code=PhoneNumberDesc(national_number_pattern='000|1(?:0[0-35-7]|1[02-5]|2[15]|9)|3372|89338|911', example_number='121', possible_length=(2, 3, 4, 5)),
    carrier_specific=PhoneNumberDesc(national_number_pattern='89338|911', example_number='89338', possible_length=(3, 5)),
    sms_services=PhoneNumberDesc(national_number_pattern='3372|89338', example_number='3372', possible_length=(4, 5)),
    short_data=True)



"""Auto-generated file, do not edit by hand. TN metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_TN = PhoneMetadata(id='TN', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='1\\d{2}', possible_length=(3,)),
    emergency=PhoneNumberDesc(national_number_pattern='19[078]', example_number='197', possible_length=(3,)),
    short_code=PhoneNumberDesc(national_number_pattern='19[078]', example_number='197', possible_length=(3,)),
    short_data=True)



"""Auto-generated file, do not edit by hand. NZ metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_NZ = PhoneMetadata(id='NZ', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='[14]\\d{2,3}', possible_length=(3, 4)),
    emergency=PhoneNumberDesc(national_number_pattern='111', example_number='111', possible_length=(3,)),
    short_code=PhoneNumberDesc(national_number_pattern='111|4098', example_number='111', possible_length=(3, 4)),
    sms_services=PhoneNumberDesc(national_number_pattern='4098', example_number='4098', possible_length=(4,)),
    short_data=True)



"""Auto-generated file, do not edit by hand. ES metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_ES = PhoneMetadata(id='ES', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='[0-379]\\d{2,5}', possible_length=(3, 4, 5, 6)),
    toll_free=PhoneNumberDesc(national_number_pattern='0(?:16|6[57]|88)|1(?:006|16\\d{3}|[3-7]\\d{2})|20\\d{4}', example_number='116111', possible_length=(3, 4, 6)),
    premium_rate=PhoneNumberDesc(national_number_pattern='1(?:18\\d{2}|2\\d{1,4})|2(?:2\\d{1,4}|[3-9]\\d{3,4})|9(?:0(?:5[124578]|7)|\\d{4,5})|[37]\\d{4,5}', example_number='23456', possible_length=(3, 4, 5, 6)),
    emergency=PhoneNumberDesc(national_number_pattern='08[58]|112', example_number='112', possible_length=(3,)),
    short_code=PhoneNumberDesc(national_number_pattern='0(?:1[0-26]|6[0-257]|8[058]|9[12])|1(?:0[03-57]\\d{1,3}|1(?:2|6(?:000|111)|8\\d{2})|2\\d{1,4}|3(?:[34]|\\d{2})|7(?:7|\\d{2})|[4-689]\\d{2})|2(?:[01]\\d{4}|2\\d{1,4}|[357]\\d{3}|80\\d{2})|3[357]\\d{3}|79[57]\\d{3}|9(?:0(?:5[124578]|7)|9[57]\\d{3})', example_number='010', possible_length=(3, 4, 5, 6)),
    standard_rate=PhoneNumberDesc(national_number_pattern='0(?:[16][0-2]|80|9[12])|21\\d{4}', example_number='211234', possible_length=(3, 6)),
    carrier_specific=PhoneNumberDesc(national_number_pattern='1(?:2\\d{1,4}|3[34]|77)|22\\d{1,4}', example_number='123', possible_length=(3, 4, 5, 6)),
    sms_services=PhoneNumberDesc(national_number_pattern='[2379]\\d{4,5}', example_number='23456', possible_length=(5, 6)),
    short_data=True)



"""Auto-generated file, do not edit by hand. 55 metadata"""
from ..phonemetadata import NumberFormat

PHONE_ALT_FORMAT_55 = [NumberFormat(pattern='(\\d{2})(\\d{8})', format='\\1 \\2', leading_digits_pattern=['[1-9][1-9]'])]



"""Auto-generated file, do not edit by hand. YT metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_YT = PhoneMetadata(id='YT', country_code=262, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='[268]\\d{8}', possible_length=(9,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='269(?:0[67]|5[01]|6\\d|[78]0)\\d{4}', example_number='269601234', possible_length=(9,)),
    mobile=PhoneNumberDesc(national_number_pattern='639(?:0[0-79]|1[019]|[26]\\d|3[09]|[45]0|7[06-9]|9[04-79])\\d{4}', example_number='639012345', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='80\\d{7}', example_number='801234567', possible_length=(9,)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    leading_digits='269|63')



"""Auto-generated file, do not edit by hand. FK metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_FK = PhoneMetadata(id='FK', country_code=500, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='[2-7]\\d{4}', possible_length=(5,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='[2-47]\\d{4}', example_number='31234', possible_length=(5,)),
    mobile=PhoneNumberDesc(national_number_pattern='[56]\\d{4}', example_number='51234', possible_length=(5,)))



"""Auto-generated file, do not edit by hand. CZ metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_CZ = PhoneMetadata(id='CZ', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='1\\d{2,5}', possible_length=(3, 4, 5, 6)),
    toll_free=PhoneNumberDesc(national_number_pattern='116(?:00[06]|111|123)', example_number='116000', possible_length=(6,)),
    emergency=PhoneNumberDesc(national_number_pattern='1(?:12|5[0568])', example_number='112', possible_length=(3,)),
    short_code=PhoneNumberDesc(national_number_pattern='1(?:1(?:2|6\\d{3}|8\\d)|2\\d{2,3}|3\\d{3,4}|4\\d{3}|5[0568]|99)', example_number='116123', possible_length=(3, 4, 5, 6)),
    short_data=True)



"""Auto-generated file, do not edit by hand. EE metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_EE = PhoneMetadata(id='EE', country_code=372, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='[3-9]\\d{6,7}|800\\d{6,7}', possible_length=(7, 8, 10)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:3[23589]|4[3-8]|6\\d|7[1-9]|88)\\d{5}', example_number='3212345', possible_length=(7,)),
    mobile=PhoneNumberDesc(national_number_pattern='(?:5\\d|8[1-5])\\d{6}|5(?:[02]\\d{2}|1(?:[0-8]\\d|95)|5[0-478]\\d|64[0-4]|65[1-589])\\d{3}', example_number='51234567', possible_length=(7, 8)),
    toll_free=PhoneNumberDesc(national_number_pattern='800(?:0\\d{3}|1\\d|[2-9])\\d{3}', example_number='80012345', possible_length=(7, 8, 10)),
    premium_rate=PhoneNumberDesc(national_number_pattern='(?:40\\d{2}|900)\\d{4}', example_number='9001234', possible_length=(7, 8)),
    personal_number=PhoneNumberDesc(national_number_pattern='70[0-2]\\d{5}', example_number='70012345', possible_length=(8,)),
    no_international_dialling=PhoneNumberDesc(national_number_pattern='800[2-9]\\d{3}', example_number='8002123', possible_length=(7,)),
    number_format=[NumberFormat(pattern='([3-79]\\d{2})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['[369]|4[3-8]|5(?:[0-2]|5[0-478]|6[45])|7[1-9]', '[369]|4[3-8]|5(?:[02]|1(?:[0-8]|95)|5[0-478]|6(?:4[0-4]|5[1-589]))|7[1-9]']),
        NumberFormat(pattern='(70)(\\d{2})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['70']),
        NumberFormat(pattern='(8000)(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['800', '8000']),
        NumberFormat(pattern='([458]\\d{3})(\\d{3,4})', format='\\1 \\2', leading_digits_pattern=['40|5|8(?:00|[1-5])', '40|5|8(?:00[1-9]|[1-5])'])],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. 506 metadata"""
from ..phonemetadata import NumberFormat

PHONE_ALT_FORMAT_506 = [NumberFormat(pattern='(\\d{4})(\\d{2})(\\d{2})', format='\\1 \\2 \\3', leading_digits_pattern=['[24-7]|8[3-9]'])]



"""Auto-generated file, do not edit by hand. CU metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_CU = PhoneMetadata(id='CU', country_code=53, international_prefix='119',
    general_desc=PhoneNumberDesc(national_number_pattern='[2-57]\\d{5,7}', possible_length=(6, 7, 8), possible_length_local_only=(4, 5)),
    fixed_line=PhoneNumberDesc(national_number_pattern='2[1-4]\\d{5,6}|3(?:1\\d{6}|[23]\\d{4,6})|4(?:[125]\\d{5,6}|[36]\\d{6}|[78]\\d{4,6})|7\\d{6,7}', example_number='71234567', possible_length=(6, 7, 8), possible_length_local_only=(4, 5)),
    mobile=PhoneNumberDesc(national_number_pattern='5\\d{7}', example_number='51234567', possible_length=(8,)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d)(\\d{6,7})', format='\\1 \\2', leading_digits_pattern=['7'], national_prefix_formatting_rule='(0\\1)'),
        NumberFormat(pattern='(\\d{2})(\\d{4,6})', format='\\1 \\2', leading_digits_pattern=['[2-4]'], national_prefix_formatting_rule='(0\\1)'),
        NumberFormat(pattern='(\\d)(\\d{7})', format='\\1 \\2', leading_digits_pattern=['5'], national_prefix_formatting_rule='0\\1')])
